| Plone Intranet

Search Role filter
Bearbeitende Einheit
Applicant
Assigned user
Type of case
Assigned to event
Archived Show archived workspaces
Earliest creation date Latest creation date
Earliest modification date Latest modification date
Earliest deadline Latest deadline

## Minifest

Nicht budgetierte einmalige Beiträge. Verein DAMP. Finanzielle Unterstützung des MinistrantInnen-Fest vom 7. September 2014 in St. Gallen.

24% Tasks finished

25 Days running

12 Modifications past 7 days

- ### Neu

  - Basisdatenerfassung

    2 Jan

  Ressort zuweisen

- ### In Bearbeitung

  - Workshop

    12 Jan

  - Hintergrundcheck machen

    12 Feb

  - Finanzcheck bzgl. früherer Zuwendungen

    14 Feb

  - Meinung Generalvikar einholen

    2 Mar

  Fertig stellen

- ### Vollständig

  - Qualitätscheck

  Einreichen

- ### Antrag

  Beschliessen

- ### Beschlossen

  - Protokoll publizieren

  - Einbuchen

  - Benachrichtigungen

  Abschliessen

- ### Abgeschlossen

  - Dankesbrief ablegen

  Archivieren

- ### Archiviert

  - Übermittlung an Staatsarchiv

## Name of case 2

Nemo enim ipsam voluptatem quia voluptas sit aspernatur aut odit aut fugit, sed quia consequuntur magni dolores eos qui ratione voluptatem sequi nesciunt.

43% Tasks finished

40 Days running

3 Modifications past 7 days

- ### Neu

  - Basisdatenerfassung

    2 Jan

  Ressort zuweisen

- ### In Bearbeitung

  - Workshop

    12 Jan

  - Hintergrundcheck machen

    12 Feb

  - Finanzcheck bzgl. früherer Zuwendungen

    14 Feb

  - Meinung Generalvikar einholen

    2 Mar

  Fertig stellen

- ### Vollständig

  - Qualitätscheck

  Einreichen

- ### Antrag

  Beschliessen

- ### Beschlossen

  - Protokoll publizieren

  - Einbuchen

  - Benachrichtigungen

  Abschliessen

- ### Abgeschlossen

  - Dankesbrief ablegen

  Archivieren

- ### Archiviert

  - Übermittlung an Staatsarchiv

## Another case Archived

"Sed ut perspiciatis unde omnis iste natus error sit voluptatem accusantium doloremque laudantium, totam rem aperiam, eaque ipsa quae ab illo inventore veritatis et quasi architecto beatae vitae dicta sunt explicabo.

2% Tasks finished

5 Days running

4 Modifications past 7 days

- ### Neu

  - Basisdatenerfassung

    2 Jan

  Ressort zuweisen

- ### In Bearbeitung

  - Workshop

    12 Jan

  - Hintergrundcheck machen

    12 Feb

  - Finanzcheck bzgl. früherer Zuwendungen

    14 Feb

  - Meinung Generalvikar einholen

    2 Mar

  Fertig stellen

- ### Vollständig

  - Qualitätscheck

  Einreichen

- ### Antrag

  Beschliessen

- ### Beschlossen

  - Protokoll publizieren

  - Einbuchen

  - Benachrichtigungen

  Abschliessen

- ### Abgeschlossen

  - Dankesbrief ablegen

  Archivieren

- ### Archiviert

  - Übermittlung an Staatsarchiv

Help